@@ -15,7 +15,7 @@ use Rose::DB::Object::Constants qw(:all);
 use Rose::DB::Constants qw(IN_TRANSACTION);
 use Rose::DB::Object::Util qw(row_id lazy_column_values_loaded_key);
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 our $Debug = 0;
 
@@ -86,7 +86,7 @@ sub db
     $self->{'db'}  = $new_db;
     $self->{'dbh'} = undef;
 
-    return $self->{'db'};
+    return $new_db;
   }
 
   return $self->{'db'} ||= $self->_init_db;
